@@ -9,7 +9,7 @@
 #
 
 package Config::Model::Describe;
-$Config::Model::Describe::VERSION = '2.091';
+$Config::Model::Describe::VERSION = '2.092';
 use Carp;
 use strict;
 use warnings;
@@ -32,6 +32,10 @@ sub describe {
     my $element = delete $args{element} ;        # optional
     my $pattern = delete $args{pattern} ;        # optional
 
+    my $tag_name = sub {
+        $_[1] .= ' /!\\' if $_[0]->has_warning;
+    };
+
     my $my_content_cb = sub {
         my ( $scanner, $data_ref, $node, @element ) = @_;
         # filter elements according to pattern
@@ -56,6 +60,7 @@ sub describe {
             if $type eq 'enum';
         push @comment, 'mandatory' if $value_obj->mandatory;
 
+        $tag_name->($value_obj,$element);
         push @$data_r, [ $name, $value, $type, join( ', ', @comment ) ];
     };
 
@@ -66,6 +71,7 @@ sub describe {
         my $list_obj = $obj->fetch_element($element);
         my $elt_type = $list_obj->cargo_type;
 
+        $tag_name->($list_obj,$element);
         if ( $elt_type eq 'node' ) {
             my $class_name = $list_obj->config_class_name;
             my @show_keys = @keys ? @keys : ('<empty>');
@@ -81,6 +87,7 @@ sub describe {
         my ( $scanner, $data_r, $obj, $element, @choices ) = @_;
 
         my $list_obj = $obj->fetch_element($element);
+        $tag_name->($list_obj,$element);
         push @$data_r, [ $element, join( ',', $list_obj->get_checked_list ), 'check_list', '' ];
     };
 
@@ -91,6 +98,7 @@ sub describe {
         my $hash_obj = $obj->fetch_element($element);
         my $elt_type = $hash_obj->cargo_type;
 
+        $tag_name->($hash_obj,$element);
         if ( $elt_type eq 'node' ) {
             my $class_name = $hash_obj->config_class_name;
             my @show_keys  = @keys ? map { qq("$_") } @keys : ('<empty>');
@@ -174,7 +182,7 @@ Config::Model::Describe - Provide a description of a node element
 
 =head1 VERSION
 
-version 2.091
+version 2.092
 
 =head1 SYNOPSIS
 
