@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Iterator;
-$Config::Model::Iterator::VERSION = '2.091';
+$Config::Model::Iterator::VERSION = '2.092';
 use Carp;
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ use Log::Log4perl qw(get_logger :levels);
 
 use Config::Model::Exception;
 
-my $logger = get_logger("Wizard::Helper");
+my $logger = get_logger("Iterator");
 
 sub new {
     my $type = shift;
@@ -165,6 +165,11 @@ sub hash_element_cb {
             @keys = $self->{scanner}->get_keys( $node, $element );
         }
 
+        if ( $self->{call_back_on_warning} and $i == 0 and $node->fetch_element($element)->has_warning ) {
+            $logger->info("hash_element_cb found elt with warning: '", $node->name, "' element $element");
+            $cb->( $self, $data_r, $node, $element, @keys );
+        }
+
         if ( $i == 1 ) {
             my $j = $self->{forward} == 1 ? 0 : $#keys;
             while ( $j >= 0 and $j < @keys ) {
@@ -276,7 +281,7 @@ Config::Model::Iterator - Iterates forward or backward a configuration tree
 
 =head1 VERSION
 
-version 2.091
+version 2.092
 
 =head1 SYNOPSIS
 
