@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Node;
-$Config::Model::Node::VERSION = '2.091';
+$Config::Model::Node::VERSION = '2.092';
 use Mouse;
 with "Config::Model::Role::NodeLoader";
 
@@ -1166,7 +1166,7 @@ sub deep_check {
 
         $deep_check_logger->debug( "deep check called on from ", $node->name, " elt $element  keys @keys" );
         return unless @keys;
-        $node->fetch_element($element)->check_content;
+        $node->fetch_element($element)->deep_check;
 
     };
 
@@ -1201,7 +1201,7 @@ Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.091
+version 2.092
 
 =head1 SYNOPSIS
 
