@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::SimpleUI;
-$Config::Model::SimpleUI::VERSION = '2.091';
+$Config::Model::SimpleUI::VERSION = '2.092';
 use Carp;
 use 5.010;
 use strict;
@@ -35,7 +35,9 @@ desc[ription] -> show class desc of current node
 desc <element>   -> show desc of element from current node
 desc <value> -> show effect of value (for enum)
 changes -> list unsaved changes
-fix -> fix most warnings (called on all elements)
+check [elt] -> run check current on current node or elt
+fix [ ! | elt ]
+  -> fix warnings in current node or of specified element or on all tree (with ! arg)
 save -> save current changes
 exit -> exit shell
 ';
@@ -175,10 +177,29 @@ my %run_dispatch = (
         }
         return '';
     },
-    fix => sub {
-        my ( $self ) = @_;
-        return $self->{root}->instance->apply_fixes;
+    check => sub {
+        my ( $self, $elt_name ) = @_;
+        if ($elt_name) {
+            $self->{current_node}->fetch_element($elt_name)->check();
+        }
+        else {
+            $self->{current_node}->check;
+        }
+        return '';
     },
+    fix => sub {
+        my ( $self, $elt_name ) = @_;
+        if ($elt_name eq '!') {
+            $self->{root}->instance->apply_fixes;
+        }
+        elsif ($elt_name) {
+            $self->{current_node}->fetch_element($elt_name)->apply_fixes;
+        }
+        else {
+            $self->{current_node}->apply_fixes;
+        }
+        return '';
+     },
     save => sub {
         my ($self) = @_;
         $self->{root}->instance->write_back();
@@ -307,7 +328,7 @@ Config::Model::SimpleUI - Simple interface for Config::Model
 
 =head1 VERSION
 
-version 2.091
+version 2.092
 
 =head1 SYNOPSIS
 
@@ -471,10 +492,16 @@ Show effect of value (for enum)
 
 Show unsaved changes
 
+=item check
+
+Without parameter, show warnings starting from current node. With an
+element name as parameter, do the same on the element.
+
 =item fix
 
-Fix most warnings by calling
-L<apply_fixes|Config::Model::Instance/apply_fixes> on instance.
+Try to fix warning starting from current node. With an element name as parameter,
+do the same on the element. With "C<!>" as parameter, try to fix warnings starting
+from root node by calling L<apply_fixes|Config::Model::Instance/apply_fixes> there.
 
 =item exit
 
