@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::TermUI;
-$Config::Model::TermUI::VERSION = '2.091';
+$Config::Model::TermUI::VERSION = '2.092';
 use Carp;
 use strict;
 use warnings;
@@ -33,6 +33,15 @@ my $leaf_completion_sub = sub {
     return @ret;
 };
 
+my $fix_completion_sub = sub {
+    my ( $self, $text, $line, $start ) = @_;
+
+    my @choice = $self->{current_node}->get_element_name;
+    push @choice, '!';
+    my @ret = grep( /^$text/, @choice );
+    return @ret;
+};
+
 # BUG: When doing autocompletion on a hash element with an index
 # containing white space (i.e. something like std_id:"abc def",
 # readline's completion insists on adding a white space after :
@@ -99,6 +108,8 @@ my %completion_dispatch = (
     desc   => $completion_sub,
     ll     => $completion_sub,
     ls     => $completion_sub,
+    check  => $completion_sub,
+    fix    => $fix_completion_sub,
     clear  => $completion_sub,
     set    => $leaf_completion_sub,
     delete => $leaf_completion_sub,
@@ -132,7 +143,7 @@ sub new {
 
     foreach my $p (qw/root title prompt/) {
         $self->{$p} = delete $args{$p}
-            or croak "WizardHelper->new: Missing $p parameter";
+            or croak "TermUI->new: Missing $p parameter";
     }
 
     $self->{current_node} = $self->{root};
@@ -211,7 +222,7 @@ Config::Model::TermUI - Interactive command line interface for cme
 
 =head1 VERSION
 
-version 2.091
+version 2.092
 
 =head1 SYNOPSIS
 
