@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2005-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -12,54 +12,54 @@
     'accept' => [
       '.*',
       {
-        'value_type' => 'uniline',
+        'description' => 'unknown parameter',
         'type' => 'leaf',
-        'description' => 'unknown parameter'
+        'value_type' => 'uniline'
       }
     ],
-    'name' => 'Fstab::Ext2FsOpt',
-    'include' => [
-      'Fstab::CommonOptions'
-    ],
-    'copyright' => [
-      '2010,2011 Dominique Dumont'
-    ],
     'author' => [
       'Dominique Dumont'
     ],
-    'license' => 'LGPL2',
+    'copyright' => [
+      '2010,2011 Dominique Dumont'
+    ],
     'element' => [
       'acl',
       {
-        'value_type' => 'boolean',
-        'type' => 'leaf'
+        'type' => 'leaf',
+        'value_type' => 'boolean'
       },
       'user_xattr',
       {
-        'value_type' => 'boolean',
+        'description' => 'Support "user." extended attributes ',
         'type' => 'leaf',
-        'description' => 'Support "user." extended attributes '
+        'value_type' => 'boolean'
       },
       'statfs_behavior',
       {
-        'value_type' => 'enum',
-        'type' => 'leaf',
         'choice' => [
           'bsddf',
           'minixdf'
-        ]
+        ],
+        'type' => 'leaf',
+        'value_type' => 'enum'
       },
       'errors',
       {
-        'value_type' => 'enum',
-        'type' => 'leaf',
         'choice' => [
           'continue',
           'remount-ro',
           'panic'
-        ]
+        ],
+        'type' => 'leaf',
+        'value_type' => 'enum'
       }
-    ]
+    ],
+    'include' => [
+      'Fstab::CommonOptions'
+    ],
+    'license' => 'LGPL2',
+    'name' => 'Fstab::Ext2FsOpt'
   }
 ]
 ;
